------------------------------------------------------------------------------
-- MakeMeGetMyMain - Alarms you when something happens to your character
------------------------------------------------------------------------------
-- Trigger_ItemSold.lua - Triggered on a sold AH item
--
-- Author: Expelliarm5s / August 2022 / All Rights Reserved
--
-- Version 1.1.19
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI ChatFrame_AddMessageEventFilter

local addonName, addon = ...
local modle = addon:NewModule("ItemSold", "AceEvent-3.0", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
local private = {}
------------------------------------------------------------------------------

function modle:ModuleName()
	return modle.moduleName
end

function modle:ToggleMod()
	addon.db.global[modle.moduleName] = addon.db.global[modle.moduleName] or false
	addon.db.global[modle.moduleName] = not addon.db.global[modle.moduleName]
	if addon.db.global[modle.moduleName] then
		addon:Printf(L["Module %s enabled"], modle.moduleName)
	else
		addon:Printf(L["Module %s disabled"], modle.moduleName)
	end
end

function modle:EnableMod()
	addon.db.global[modle.moduleName] = true
	addon:Printf(L["Module %s enabled"], modle.moduleName)
end

function modle:DisableMod()
	addon.db.global[modle.moduleName] = false
	addon:Printf(L["Module %s disabled"], modle.moduleName)
end

function modle:ModuleIcon()
	if addon.isClassic then
		return "INTERFACE\\ICONS\\INV_Misc_Coin_01"
	else
		return "INTERFACE\\ICONS\\INV_Misc_Coin_01"
	end
end

function modle:TriggerName()
	return L["AH item sold!"]
end

function modle:TriggerDesc()
	return L["Alarm fires on sold AH item."]
end

function modle:Login()
	if addon.isClassic then
		ChatFrame_AddMessageEventFilter("CHAT_MSG_SYSTEM", private.MSG_SYSTEM)
		addon:DebugPrintf(modle.moduleName .. "~  active Classic")
	else
		modle:RegisterEvent("AUCTION_HOUSE_SHOW_NOTIFICATION", private.MSG_AUCTION_HOUSE)
		modle:RegisterEvent("AUCTION_HOUSE_SHOW_FORMATTED_NOTIFICATION", private.MSG_AUCTION_HOUSE)
		addon:DebugPrintf(modle.moduleName .. "~  active nonClassic")
	end
end

function private.MSG_SYSTEM(_, _, msg, arg1, arg2)
	addon:DebugPrintf(modle.moduleName .. "~  msg=%s", tostring(msg), tostring(arg1), tostring(arg2))

	local item = nil
	local matchstr

	-- normal SYSTEM msg
	if not item then
		matchstr = ERR_AUCTION_SOLD_S
		matchstr = string.gsub(matchstr, "%%1$s", "(.*)")
		item = string.match(msg, matchstr)
		addon:DebugPrintf(modle.moduleName .. "~  Test on SYSTEM msg '%s': %s", tostring(matchstr), tostring(item))
	end
	-- modified SYSTEM msg by TSM
	local tsmstr = {"Your auction of (.*) has sold for",
		"Deine Auktion (.*) wurde für",
		"Votre enchère (.*) a été vendue pour",
		"Tu subasta (.*) ha sido vendida por",
		"¡Tu subasta de (.*) se ha vendido por",
		"La tua asta di (.*) è stata venduta per",
		"Seu leilão (.*) foi vendido por",
		"Ваш лот (.*) был продан за", }
	for _, m in ipairs(tsmstr) do
		if not item then
			matchstr = m
			item = string.match(msg, matchstr)
			addon:DebugPrintf(modle.moduleName .. "~  Test for TSM msg '%s': %s", tostring(matchstr), tostring(item))
		end
	end

	if item then
		if addon.isEnabled and addon.db.global[modle.moduleName] then
			addon:DebugPrintf(modle.moduleName .. "~  -> GUI:Fire(%s)", modle.moduleName)
			addon:Printf(format(L["Module %s: %s (%s)"], modle.moduleName, modle:TriggerName(), tostring(item)))
			if addon.GUI.Fire then
				addon.GUI:Fire(modle.moduleName, nil, tostring(item))
			end
		end
	end
end

function private.MSG_AUCTION_HOUSE(_, msg, item)
	addon:DebugPrintf(modle.moduleName .. "~  msg=%s, item=%s", tostring(msg), tostring(item))

	if msg == Enum.AuctionHouseNotification.AuctionSold and item then
		if addon.isEnabled and addon.db.global[modle.moduleName] then
			addon:DebugPrintf(modle.moduleName .. "~  -> GUI:Fire(%s)", modle.moduleName)
			addon:Printf(format(L["Module %s: %s (%s)"], modle.moduleName, modle:TriggerName(), tostring(item)))
			if addon.GUI.Fire then
				addon.GUI:Fire(modle.moduleName, nil, tostring(item))
			end
		end
	end
end

-- EOF